@@ -32,8 +32,7 @@ probe.internal <- function (object, probes, params, nsim = 1L, seed = NULL, ...)
     datval <- tryCatch(
         .Call(apply_probe_data,object,probes),
         error = function (e) {
-            stop(ep,"applying probes to actual data: ",
-                 conditionMessage(e),call.=FALSE)
+            stop(ep,"applying probes to actual data: ",conditionMessage(e),call.=FALSE)
         }
     )
     nprobes <- length(datval)
@@ -50,8 +49,7 @@ probe.internal <- function (object, probes, params, nsim = 1L, seed = NULL, ...)
             datval=datval
         ),
         error = function (e) {
-            stop(ep,"applying probes to simulated data: ",
-                 conditionMessage(e),call.=FALSE)
+            stop(ep,"applying probes to simulated data: ",conditionMessage(e),call.=FALSE)
         }
     )
     
@@ -66,7 +64,12 @@ probe.internal <- function (object, probes, params, nsim = 1L, seed = NULL, ...)
         quants[k] <- sum(simval[,k]<datval[k])/nsim
     }
 
-    ll <- .Call(synth_loglik,simval,datval)
+    ll <- tryCatch(
+        .Call(synth_loglik,simval,datval),
+        error = function (e) {
+            stop(ep,"in synthetic likelihood computation: ",conditionMessage(e),call.=FALSE)
+        }
+    )
 
     coef(object) <- params
 
